@@ -1,13 +1,10 @@
+from .data import DomainCandidateTermList, PageCandidateTermList, PDFCandidateTermList
 from .extractor import CandidateTermExtractor
-from .data import (
-    PageCandidateTermList,
-    PDFCandidateTermList,
-    DomainCandidateTermList,
-)
 
+# isort: unique-list
 __all__ = [
     "CandidateTermExtractor",
-    "PageCandidateTermList",
-    "PDFCandidateTermList",
     "DomainCandidateTermList",
+    "PDFCandidateTermList",
+    "PageCandidateTermList",
 ]
