@@ -2,7 +2,7 @@ import re
 
 from py_pdf_term._common.consts import ALPHABET_REGEX, HIRAGANA_REGEX, KATAKANA_REGEX
 from py_pdf_term._common.data import Term
-from py_pdf_term.tokenizer.langs import JapaneseTokenClassifier
+from ....classifiers import JapaneseTokenClassifier
 
 from ..base import BaseJapaneseCandidateTermFilter
 
@@ -17,7 +17,7 @@ class JapaneseConcatenationFilter(BaseJapaneseCandidateTermFilter):
         return (
             self._is_norn_phrase(scoped_term)
             and not self._has_invalid_connector_symbol(scoped_term)
-            and not self._has_invalid_modifying_particle(scoped_term)
+            and not self._has_invalid_connector_term(scoped_term)
             and not self._has_invalid_prefix(scoped_term)
             and not self._has_invalid_postfix(scoped_term)
             and not self._has_invalid_adjective(scoped_term)
@@ -33,7 +33,7 @@ class JapaneseConcatenationFilter(BaseJapaneseCandidateTermFilter):
         induces_should_be_norn = [
             i - 1
             for i in range(1, num_tokens)
-            if self._classifier.is_modifying_particle(scoped_term.tokens[i])
+            if self._classifier.is_connector_term(scoped_term.tokens[i])
         ] + [num_tokens - 1]
 
         return all(map(norn_or_postfix_appears_at, induces_should_be_norn))
@@ -53,25 +53,25 @@ class JapaneseConcatenationFilter(BaseJapaneseCandidateTermFilter):
 
         return any(map(invalid_connector_symbol_appears_at, range(num_tokens)))
 
-    def _has_invalid_modifying_particle(self, scoped_term: Term) -> bool:
+    def _has_invalid_connector_term(self, scoped_term: Term) -> bool:
         num_tokens = len(scoped_term.tokens)
         phonetic_regex = re.compile(PHONETIC_REGEX)
 
-        def invalid_modifying_particle_appears_at(i: int) -> bool:
-            if not self._classifier.is_modifying_particle(scoped_term.tokens[i]):
+        def invalid_connector_symbol_appears_at(i: int) -> bool:
+            if not self._classifier.is_connector_term(scoped_term.tokens[i]):
                 return False
             return (
                 i == 0
                 or i == num_tokens - 1
-                or scoped_term.tokens[i - 1].pos == "助詞"
-                or scoped_term.tokens[i + 1].pos == "助詞"
+                or self._classifier.is_connector_term(scoped_term.tokens[i - 1])
+                or self._classifier.is_connector_term(scoped_term.tokens[i + 1])
                 or self._classifier.is_symbol(scoped_term.tokens[i - 1])
                 or self._classifier.is_symbol(scoped_term.tokens[i + 1])
                 or phonetic_regex.fullmatch(str(scoped_term.tokens[i - 1])) is not None
                 or phonetic_regex.fullmatch(str(scoped_term.tokens[i + 1])) is not None
             )
 
-        return any(map(invalid_modifying_particle_appears_at, range(num_tokens)))
+        return any(map(invalid_connector_symbol_appears_at, range(num_tokens)))
 
     def _has_invalid_prefix(self, scoped_term: Term) -> bool:
         num_tokens = len(scoped_term.tokens)
