@@ -1,7 +1,5 @@
-from .japanese import JapaneseSymbolLikeFilter
 from .english import EnglishSymbolLikeFilter
+from .japanese import JapaneseSymbolLikeFilter
 
-__all__ = [
-    "JapaneseSymbolLikeFilter",
-    "EnglishSymbolLikeFilter",
-]
+# isort: unique-list
+__all__ = ["EnglishSymbolLikeFilter", "JapaneseSymbolLikeFilter"]
