@@ -3,7 +3,7 @@ import re
 from py_pdf_term._common.consts import ALPHABET_REGEX, NUMBER_REGEX
 from py_pdf_term._common.data import Term
 from py_pdf_term.tokenizer import Token
-from py_pdf_term.tokenizer.langs import EnglishTokenClassifier
+from ....classifiers import EnglishTokenClassifier
 
 from ..base import BaseEnglishCandidateTermFilter
 
