@@ -1,7 +1,5 @@
-from .single import SingleDomainRankingMethodMapper
 from .multi import MultiDomainRankingMethodMapper
+from .single import SingleDomainRankingMethodMapper
 
-__all__ = [
-    "SingleDomainRankingMethodMapper",
-    "MultiDomainRankingMethodMapper",
-]
+# isort: unique-list
+__all__ = ["MultiDomainRankingMethodMapper", "SingleDomainRankingMethodMapper"]
