@@ -1,8 +1,6 @@
 from py_pdf_term._common.data import ScoredTerm, Term
 from py_pdf_term._common.extended_math import extended_log10
 from py_pdf_term.candidates import DomainCandidateTermList
-from py_pdf_term.tokenizer import Token
-from py_pdf_term.tokenizer.langs import EnglishTokenClassifier, JapaneseTokenClassifier
 
 from ..data import MethodTermRanking
 from ..rankingdata import FLRRankingData
@@ -11,8 +9,7 @@ from .base import BaseSingleDomainRanker
 
 class FLRRanker(BaseSingleDomainRanker[FLRRankingData]):
     def __init__(self) -> None:
-        self._ja_classifier = JapaneseTokenClassifier()
-        self._en_classifier = EnglishTokenClassifier()
+        pass
 
     def rank_terms(
         self, domain_candidates: DomainCandidateTermList, ranking_data: FLRRankingData
@@ -35,16 +32,13 @@ class FLRRanker(BaseSingleDomainRanker[FLRRankingData]):
         candidate_lemma = candidate.lemma()
         num_tokens = len(candidate.tokens)
         num_meaningless_tokens = sum(
-            map(
-                lambda token: 1 if self._is_meaningless_token(token) else 0,
-                candidate.tokens,
-            )
+            map(lambda token: 1 if token.is_meaningless else 0, candidate.tokens)
         )
         term_freq_score = extended_log10(ranking_data.term_freq.get(candidate_lemma, 0))
 
         concat_score = 0.0
         for token in candidate.tokens:
-            if self._is_meaningless_token(token):
+            if token.is_meaningless:
                 continue
 
             lscore = sum(ranking_data.left_freq.get(token.lemma, dict()).values())
@@ -55,8 +49,3 @@ class FLRRanker(BaseSingleDomainRanker[FLRRankingData]):
 
         score = term_freq_score + concat_score
         return ScoredTerm(candidate_lemma, score)
-
-    def _is_meaningless_token(self, token: Token) -> bool:
-        is_ja_meaningless = self._ja_classifier.is_meaningless(token)
-        is_en_meaningless = self._en_classifier.is_meaningless(token)
-        return is_ja_meaningless or is_en_meaningless
