@@ -2,7 +2,6 @@ from .base import BaseRankingData, RankingData
 from .flr import FLRRankingData
 from .flrh import FLRHRankingData
 from .hits import HITSRankingData
-from .lfidf import LFIDFRankingData
 from .mcvalue import MCValueRankingData
 from .mdp import MDPRankingData
 from .tfidf import TFIDFRankingData
@@ -13,7 +12,6 @@ __all__ = [
     "FLRHRankingData",
     "FLRRankingData",
     "HITSRankingData",
-    "LFIDFRankingData",
     "MCValueRankingData",
     "MDPRankingData",
     "RankingData",
